<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  
  <xsl:include href="style.xsl"/>
  <xsl:include href="service-params.xsl"/>
  <xsl:include href="querytools.xsl"/>
  
  <xsl:output method="html"/>

  <xsl:template name="pageHead">
    <head>
      <title><xsl:call-template name="text"><xsl:with-param name="key">gsdl</xsl:with-param></xsl:call-template></title>
    </head>
  </xsl:template>

  <xsl:template match="pageResponse">
    <xsl:variable name="collName"><xsl:value-of select="ancestor::page/pageRequest/paramList/param[@name='c']/@value"/></xsl:variable>
    <xsl:variable name='library' select='ancestor::page/pageExtra/config/library_name'/>
    <center>
      <xsl:call-template name="collectionPageBanner">
	<xsl:with-param name="collName" select="$collName"/>
      </xsl:call-template>
      <xsl:apply-templates select="service">
	<xsl:with-param name="collName" select="$collName"/>
      </xsl:apply-templates>
    </center>

    <xsl:if test="documentNodeList">
      <xsl:call-template name="query-response">
	<xsl:with-param name="library" select="$library"/>
	<xsl:with-param name="collName" select="$collName"/>
      </xsl:call-template>
    </xsl:if>
    <xsl:call-template name="greenBar"/>
  </xsl:template>
  
  <xsl:template name="query-response">
    <xsl:param name="library"/>
    <xsl:param name="collName"/>
    <xsl:call-template name="greenBarResults"/>
    
    <!-- If query term information is available, display it -->
    <br/>
    <xsl:if test="count(termList/term) > 0">
      <small>
	<xsl:call-template name="text"><xsl:with-param name="key">query.wordcount</xsl:with-param></xsl:call-template> 
	<xsl:for-each select="termList/term">
	  <xsl:if test="position() > 1">, </xsl:if>
	  <xsl:value-of select="@name"/>: <xsl:value-of select="@freq"/> 
	</xsl:for-each>
      </small>
      <br/>
    </xsl:if>
    
    <!-- If the number of matching documents is known, display it -->
    <xsl:variable name="numDocsMatched" select="metadataList/metadata[@name='numDocsMatched']/@value"/>
    <xsl:if test="$numDocsMatched">
      <xsl:choose>
	<xsl:when test="$numDocsMatched='0'">
	  <xsl:call-template name="text"><xsl:with-param name="key">query.nodocsmatch</xsl:with-param></xsl:call-template>
	</xsl:when>
	<xsl:when test="$numDocsMatched='1'">
	  <xsl:call-template name="text"><xsl:with-param name="key">query.onedocsmatch</xsl:with-param></xsl:call-template>
	</xsl:when>
	<xsl:otherwise>
	  <xsl:value-of select="$numDocsMatched"/> documents matched the query.
	</xsl:otherwise>
      </xsl:choose>
    </xsl:if>
    
    <!-- next and prev links at top of results-->
    <xsl:call-template name="result-navigation"><xsl:with-param name="library" select="$library"/></xsl:call-template>
    <!-- Display the matching documents -->
    <xsl:variable name="hp"><xsl:choose><xsl:when test="ancestor::page/pageRequest/paramList/param[@name='hp']"><xsl:value-of select="ancestor::page/pageRequest/paramList/param[@name='hp']/@value"/></xsl:when><xsl:otherwise>20</xsl:otherwise></xsl:choose></xsl:variable>
    <xsl:variable name="hn" select="ancestor::page/pageRequest/paramList/param[@name='hn']/@value"/>      
    <table>
      <tr valign="top">
	<xsl:for-each select="documentNodeList/documentNode">
	  <xsl:if test="position()&gt; (($hn - 1)*$hp) and position() &lt;= ($hn * $hp)">
	    <tr>
	      <xsl:apply-templates select=".">
		<xsl:with-param name="collName" select="$collName"/>
	      </xsl:apply-templates>
	    </tr>
	  </xsl:if>
	</xsl:for-each>
      </tr>
    </table>
    <!-- next and prev links at bottom of page -->
    <xsl:call-template name="result-navigation"><xsl:with-param name="library" select="$library"/></xsl:call-template>
  </xsl:template>



  <xsl:template match="service">
    <xsl:param name="collName"/>
    <xsl:variable name="subaction" select="../pageRequest/@subaction"/>
    <xsl:variable name='library' select='ancestor::page/pageExtra/config/library_name'/>
    <h3><xsl:value-of select="display/name"/></h3><p/>
    <form name="QueryForm" method="get" action="/gsdl3/{$library}">
      <input type="hidden" name="a" value="q"/>
      <input type="hidden" name="sa" value="{$subaction}"/>
      <input type="hidden" name="rt" value="r"/>
      <input type="hidden" name="s" value="{@name}"/>
      <input type="hidden" name="c" value="{$collName}"/>
      <input type="hidden" name="hn" value="1"/>
      <xsl:apply-templates select="paramList"/>
      <input type="submit"><xsl:attribute name="value"><xsl:value-of select='display/submit'/></xsl:attribute></input>
    </form>
  </xsl:template>
  
  
  <xsl:template match="paramList">
    <p/><table width="537">
      <xsl:for-each select="param">
	<xsl:choose>
	  <xsl:when test="@type='multi'">
	    <tr><td colspan='2'>
		<xsl:apply-templates select='.'/></td></tr>
	  </xsl:when>
	  <xsl:otherwise>
	    <xsl:variable name="pname" select="@name"/>
	    <xsl:variable name="pvalue"><xsl:choose><xsl:when test="ancestor::page/pageRequest/paramList/param[@name=$pname]"><xsl:value-of select="ancestor::page/pageRequest/paramList/param[@name=$pname]/@value"/></xsl:when><xsl:otherwise><xsl:value-of select="@default"/></xsl:otherwise></xsl:choose></xsl:variable>
	    <tr><td><xsl:value-of select='ancestor::service/display/param[@name=$pname]/name'/></td><td align="right"><xsl:apply-templates select="."><xsl:with-param name="default" select="$pvalue"/></xsl:apply-templates></td></tr>
	  </xsl:otherwise>
	</xsl:choose>
      </xsl:for-each>
    </table>
  </xsl:template>
  
  
  <!-- a param list that puts params in pairs- wont work as is with new
  param handling stuff -->
  <!--
  <xsl:template match="paramList">
  <p/><table width="537">
  <xsl:choose>
  <xsl:when test='count(param)>4'>
  <xsl:for-each select="param[position() mod 2 = 1]"> 
  <tr><xsl:apply-templates select="."/>
  <xsl:if test="following-sibling::param[1]"><xsl:apply-templates select='following-sibling::param[1]'/></xsl:if></tr>
</xsl:for-each>
</xsl:when>
  <xsl:otherwise>
  <xsl:for-each select="param">
  <tr><xsl:apply-templates select='.'/></tr>
</xsl:for-each>
</xsl:otherwise>
</xsl:choose>
</table>
</xsl:template>
  -->

  <!-- the default doc node template for the query results -->
  <!-- eventually shouldn't need sib arg here -->
  <xsl:template match="documentNode">
    <xsl:param name="collName"/>
    <xsl:variable name="library" select="ancestor::page/pageExtra/config/library_name"/>
    
    <td>
      <a><xsl:attribute name="href"><xsl:value-of select='$library'/>?a=d&amp;c=<xsl:value-of select='$collName'/>&amp;d=<xsl:value-of select='@nodeID'/><xsl:if test="@nodeType='leaf'">&amp;sib=1</xsl:if></xsl:attribute>
	<xsl:apply-templates select="." mode="displayNodeIcon"/>
      </a>
    </td>
    <td><xsl:value-of select="metadataList/metadata[@name='Title']"/></td>
  </xsl:template>
  
  
  <xsl:template name="greenBarResults">
    <p/>
    <center>
      <img src="interfaces/default/images/qryresb.gif" width="537" height="17"/>
    </center>
  </xsl:template>
  
</xsl:stylesheet>  
